# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`puppetboard`](#puppetboard): Base class for Puppetboard. Sets up the user and python environment.
* [`puppetboard::apache::conf`](#puppetboardapacheconf): Creates an entry in your apache configuration directory to run PuppetBoard server-wide (i.e. not in a vhost).
* [`puppetboard::apache::vhost`](#puppetboardapachevhost): Sets up an apache::vhost to run PuppetBoard, and writes an appropriate wsgi.py from template

### Data types

* [`Puppetboard::Syslogpriority`](#puppetboardsyslogpriority): type for the different Python log levels

## Classes

### <a name="puppetboard"></a>`puppetboard`

class { 'puppetboard':
   user  => 'pboard',
   group => 'pboard',
   basedir => '/www/puppetboard'
 } ->
 class { 'puppetboard::apache::conf':
   user  => 'pboard',
   group => 'pboard',
   basedir => '/www/puppetboard'
 }

#### Examples

##### 

```puppet
configure puppetboard with an apache config for a subpath (http://$fqdn/puppetboard)
```

#### Parameters

The following parameters are available in the `puppetboard` class:

* [`install_from`](#install_from)
* [`user`](#user)
* [`homedir`](#homedir)
* [`group`](#group)
* [`groups`](#groups)
* [`basedir`](#basedir)
* [`git_source`](#git_source)
* [`puppetdb_host`](#puppetdb_host)
* [`puppetdb_port`](#puppetdb_port)
* [`puppetdb_key`](#puppetdb_key)
* [`puppetdb_ssl_verify`](#puppetdb_ssl_verify)
* [`puppetdb_cert`](#puppetdb_cert)
* [`puppetdb_timeout`](#puppetdb_timeout)
* [`dev_listen_host`](#dev_listen_host)
* [`dev_listen_port`](#dev_listen_port)
* [`unresponsive`](#unresponsive)
* [`enable_catalog`](#enable_catalog)
* [`enable_query`](#enable_query)
* [`offline_mode`](#offline_mode)
* [`localise_timestamp`](#localise_timestamp)
* [`python_loglevel`](#python_loglevel)
* [`python_proxy`](#python_proxy)
* [`python_index`](#python_index)
* [`default_environment`](#default_environment)
* [`experimental`](#experimental)
* [`revision`](#revision)
* [`manage_git`](#manage_git)
* [`manage_virtualenv`](#manage_virtualenv)
* [`python_version`](#python_version)
* [`virtualenv_dir`](#virtualenv_dir)
* [`manage_user`](#manage_user)
* [`manage_group`](#manage_group)
* [`package_name`](#package_name)
* [`manage_selinux`](#manage_selinux)
* [`reports_count`](#reports_count)
* [`settings_file`](#settings_file)
* [`extra_settings`](#extra_settings)
* [`override`](#override)
* [`enable_ldap_auth`](#enable_ldap_auth)
* [`ldap_require_group`](#ldap_require_group)
* [`apache_confd`](#apache_confd)
* [`apache_service`](#apache_service)

##### <a name="install_from"></a>`install_from`

Data type: `Enum['package', 'vcsrepo']`

Specify how the package should be installed

Default value: `'vcsrepo'`

##### <a name="user"></a>`user`

Data type: `String`

Puppetboard system user.

Default value: `'puppetboard'`

##### <a name="homedir"></a>`homedir`

Data type: `Optional[Stdlib::Absolutepath]`

Puppetboard system user's home directory.

Default value: ``undef``

##### <a name="group"></a>`group`

Data type: `String`

Puppetboard system group.

Default value: `'puppetboard'`

##### <a name="groups"></a>`groups`

Data type: `Optional[Variant[String[1], Array[String[1]]]]`

additional groups for the user that runs puppetboard

Default value: ``undef``

##### <a name="basedir"></a>`basedir`

Data type: `Stdlib::AbsolutePath`

Base directory where to build puppetboard vcsrepo and python virtualenv.

Default value: `'/srv/puppetboard'`

##### <a name="git_source"></a>`git_source`

Data type: `String`

Location of upstream Puppetboard GIT repository

Default value: `'https://github.com/voxpupuli/puppetboard'`

##### <a name="puppetdb_host"></a>`puppetdb_host`

Data type: `String`

PuppetDB Host

Default value: `'127.0.0.1'`

##### <a name="puppetdb_port"></a>`puppetdb_port`

Data type: `Stdlib::Port`

PuppetDB Port

Default value: `8080`

##### <a name="puppetdb_key"></a>`puppetdb_key`

Data type: `Optional[Stdlib::AbsolutePath]`

path to PuppetMaster/CA signed client SSL key

Default value: ``undef``

##### <a name="puppetdb_ssl_verify"></a>`puppetdb_ssl_verify`

Data type: `Variant[Boolean, Stdlib::AbsolutePath]`

whether PuppetDB uses SSL or not (true or false), or the path to the puppet CA

Default value: ``false``

##### <a name="puppetdb_cert"></a>`puppetdb_cert`

Data type: `Optional[Stdlib::AbsolutePath]`

path to PuppetMaster/CA signed client SSL cert

Default value: ``undef``

##### <a name="puppetdb_timeout"></a>`puppetdb_timeout`

Data type: `Integer[0]`

timeout, in seconds, for connecting to PuppetDB

Default value: `20`

##### <a name="dev_listen_host"></a>`dev_listen_host`

Data type: `String`

host that dev server binds to/listens on

Default value: `'127.0.0.1'`

##### <a name="dev_listen_port"></a>`dev_listen_port`

Data type: `Stdlib::Port`

port that dev server binds to/listens on

Default value: `5000`

##### <a name="unresponsive"></a>`unresponsive`

Data type: `Integer[0]`

number of hours after which a node is considered "unresponsive"

Default value: `3`

##### <a name="enable_catalog"></a>`enable_catalog`

Data type: `Boolean`

Whether to allow the user to browser catalog comparisons.

Default value: ``false``

##### <a name="enable_query"></a>`enable_query`

Data type: `Boolean`

Whether to allow the user to run raw queries against PuppetDB.

Default value: ``true``

##### <a name="offline_mode"></a>`offline_mode`

Data type: `Boolean`

Weather to load static assents (jquery, semantic-ui, tablesorter, etc)

Default value: ``false``

##### <a name="localise_timestamp"></a>`localise_timestamp`

Data type: `Boolean`

Whether to localise the timestamps in the UI.

Default value: ``true``

##### <a name="python_loglevel"></a>`python_loglevel`

Data type: `Puppetboard::Syslogpriority`

Python logging module log level.

Default value: `'info'`

##### <a name="python_proxy"></a>`python_proxy`

Data type: `Optional[String[1]]`

HTTP proxy server to use for pip/virtualenv.

Default value: ``undef``

##### <a name="python_index"></a>`python_index`

Data type: `Optional[String[1]]`

HTTP index server to use for pip/virtualenv.

Default value: ``undef``

##### <a name="default_environment"></a>`default_environment`

Data type: `String[1]`

set the default environment

Default value: `'production'`

##### <a name="experimental"></a>`experimental`

Data type: `Boolean`

Enable experimental features.

Default value: ``false``

##### <a name="revision"></a>`revision`

Data type: `Optional[String]`

Commit, tag, or branch from Puppetboard's Git repo to be used

Default value: ``undef``

##### <a name="manage_git"></a>`manage_git`

Data type: `Boolean`

If true, require the git package. If false do nothing.

Default value: ``false``

##### <a name="manage_virtualenv"></a>`manage_virtualenv`

Data type: `Boolean`

If true, require the virtualenv package. If false do nothing.

Default value: ``false``

##### <a name="python_version"></a>`python_version`

Data type: `Pattern[/^3\.\d$/]`

Python version to use in virtualenv.

##### <a name="virtualenv_dir"></a>`virtualenv_dir`

Data type: `Stdlib::Absolutepath`

Set location where virtualenv will be installed

Default value: `"${basedir}/virtenv-puppetboard"`

##### <a name="manage_user"></a>`manage_user`

Data type: `Boolean`

If true, manage (create) this group. If false do nothing.

Default value: ``true``

##### <a name="manage_group"></a>`manage_group`

Data type: `Boolean`

If true, manage (create) this group. If false do nothing.

Default value: ``true``

##### <a name="package_name"></a>`package_name`

Data type: `Optional[String[1]]`

Name of the package to install puppetboard

Default value: ``undef``

##### <a name="manage_selinux"></a>`manage_selinux`

Data type: `Boolean`

If true, manage selinux policies for puppetboard. If false do nothing.

Default value: `pick($facts['os.selinux.enabled'], false)`

##### <a name="reports_count"></a>`reports_count`

Data type: `Integer[0]`

This is the number of reports that we want the dashboard to display.

Default value: `10`

##### <a name="settings_file"></a>`settings_file`

Data type: `Stdlib::Absolutepath`

Path to puppetboard configuration file

Default value: `"${basedir}/puppetboard/settings.py"`

##### <a name="extra_settings"></a>`extra_settings`

Data type: `Hash`

Defaults to an empty hash '{}'. Used to pass in arbitrary key/value

Default value: `{}`

##### <a name="override"></a>`override`

Data type: `String[1]`

Sets the Apache AllowOverride value

Default value: `'None'`

##### <a name="enable_ldap_auth"></a>`enable_ldap_auth`

Data type: `Boolean`

Whether to enable LDAP auth

Default value: ``false``

##### <a name="ldap_require_group"></a>`ldap_require_group`

Data type: `Boolean`

LDAP group to require on login

Default value: ``false``

##### <a name="apache_confd"></a>`apache_confd`

Data type: `Stdlib::Absolutepath`

path to the apache2 vhost directory

##### <a name="apache_service"></a>`apache_service`

Data type: `String[1]`

name of the apache2 service

### <a name="puppetboardapacheconf"></a>`puppetboard::apache::conf`

Creates an entry in your apache configuration directory to run PuppetBoard server-wide (i.e. not in a vhost).

* **Note** Make sure you have purge_configs set to false in your apache class!

#### Parameters

The following parameters are available in the `puppetboard::apache::conf` class:

* [`wsgi_alias`](#wsgi_alias)
* [`threads`](#threads)
* [`max_reqs`](#max_reqs)
* [`user`](#user)
* [`group`](#group)
* [`basedir`](#basedir)
* [`enable_ldap_auth`](#enable_ldap_auth)
* [`ldap_bind_dn`](#ldap_bind_dn)
* [`ldap_bind_password`](#ldap_bind_password)
* [`ldap_url`](#ldap_url)
* [`ldap_bind_authoritative`](#ldap_bind_authoritative)
* [`ldap_require_group`](#ldap_require_group)
* [`ldap_require_group_dn`](#ldap_require_group_dn)
* [`virtualenv_dir`](#virtualenv_dir)

##### <a name="wsgi_alias"></a>`wsgi_alias`

Data type: `Stdlib::Unixpath`

WSGI script alias source

Default value: `'/puppetboard'`

##### <a name="threads"></a>`threads`

Data type: `Integer[1]`

Number of WSGI threads to use

Default value: `5`

##### <a name="max_reqs"></a>`max_reqs`

Data type: `Integer[0]`

Limit on number of requests allowed to daemon process Defaults to 0 (no limit)

Default value: `0`

##### <a name="user"></a>`user`

Data type: `String[1]`

WSGI daemon process user, and daemon process name

Default value: `$puppetboard::user`

##### <a name="group"></a>`group`

Data type: `String[1]`

WSGI daemon process group owner, and daemon process group

Default value: `$puppetboard::group`

##### <a name="basedir"></a>`basedir`

Data type: `Stdlib::AbsolutePath`

Base directory where to build puppetboard vcsrepo and python virtualenv.

Default value: `$puppetboard::basedir`

##### <a name="enable_ldap_auth"></a>`enable_ldap_auth`

Data type: `Boolean`

Whether to enable LDAP auth

Default value: `$puppetboard::enable_ldap_auth`

##### <a name="ldap_bind_dn"></a>`ldap_bind_dn`

Data type: `Optional[String[1]]`

LDAP Bind DN

Default value: ``undef``

##### <a name="ldap_bind_password"></a>`ldap_bind_password`

Data type: `Optional[String[1]]`

LDAP password

Default value: ``undef``

##### <a name="ldap_url"></a>`ldap_url`

Data type: `Optional[String[1]]`

LDAP connection string

Default value: ``undef``

##### <a name="ldap_bind_authoritative"></a>`ldap_bind_authoritative`

Data type: `Optional[String[1]]`

Determines if other authentication providers are used when a user can be mapped to a DN but the server cannot bind with the credentials

Default value: ``undef``

##### <a name="ldap_require_group"></a>`ldap_require_group`

Data type: `Boolean`

LDAP group to require on login

Default value: `$puppetboard::ldap_require_group`

##### <a name="ldap_require_group_dn"></a>`ldap_require_group_dn`

Data type: `Optional[String[1]]`

LDAP group DN for LDAP group

Default value: ``undef``

##### <a name="virtualenv_dir"></a>`virtualenv_dir`

Data type: `Stdlib::Absolutepath`

Set location where virtualenv will be installed

Default value: `$puppetboard::virtualenv_dir`

### <a name="puppetboardapachevhost"></a>`puppetboard::apache::vhost`

Sets up an apache::vhost to run PuppetBoard, and writes an appropriate wsgi.py from template

#### Parameters

The following parameters are available in the `puppetboard::apache::vhost` class:

* [`vhost_name`](#vhost_name)
* [`wsgi_alias`](#wsgi_alias)
* [`ip`](#ip)
* [`port`](#port)
* [`ssl`](#ssl)
* [`ssl_cert`](#ssl_cert)
* [`ssl_key`](#ssl_key)
* [`ssl_chain`](#ssl_chain)
* [`threads`](#threads)
* [`user`](#user)
* [`group`](#group)
* [`basedir`](#basedir)
* [`override`](#override)
* [`enable_ldap_auth`](#enable_ldap_auth)
* [`ldap_bind_dn`](#ldap_bind_dn)
* [`ldap_bind_password`](#ldap_bind_password)
* [`ldap_url`](#ldap_url)
* [`ldap_bind_authoritative`](#ldap_bind_authoritative)
* [`ldap_require_group`](#ldap_require_group)
* [`ldap_require_group_dn`](#ldap_require_group_dn)
* [`virtualenv_dir`](#virtualenv_dir)
* [`custom_apache_parameters`](#custom_apache_parameters)

##### <a name="vhost_name"></a>`vhost_name`

Data type: `String[1]`

The vhost ServerName.

##### <a name="wsgi_alias"></a>`wsgi_alias`

Data type: `Stdlib::Unixpath`

WSGI script alias source

Default value: `'/'`

##### <a name="ip"></a>`ip`

Data type: `Optional[Stdlib::IP::Address]`

IP for the vhost to bind to

Default value: ``undef``

##### <a name="port"></a>`port`

Data type: `Stdlib::Port`

Port for the vhost to listen on.

Default value: `5000`

##### <a name="ssl"></a>`ssl`

Data type: `Boolean`

If vhost should be configured with ssl

Default value: ``false``

##### <a name="ssl_cert"></a>`ssl_cert`

Data type: `Optional[Stdlib::AbsolutePath]`

Path to server SSL cert

Default value: ``undef``

##### <a name="ssl_key"></a>`ssl_key`

Data type: `Optional[Stdlib::AbsolutePath]`

Path to server SSL key

Default value: ``undef``

##### <a name="ssl_chain"></a>`ssl_chain`

Data type: `Optional[Stdlib::AbsolutePath]`

Path to server CA Chain file

Default value: ``undef``

##### <a name="threads"></a>`threads`

Data type: `Integer[1]`

Number of WSGI threads to use.

Default value: `5`

##### <a name="user"></a>`user`

Data type: `String[1]`

WSGI daemon process user, and daemon process name

Default value: `$puppetboard::user`

##### <a name="group"></a>`group`

Data type: `String[1]`

WSGI daemon process group owner, and daemon process group

Default value: `$puppetboard::group`

##### <a name="basedir"></a>`basedir`

Data type: `Stdlib::AbsolutePath`

Base directory where to build puppetboard vcsrepo and python virtualenv.

Default value: `$puppetboard::basedir`

##### <a name="override"></a>`override`

Data type: `String[1]`

Sets the Apache AllowOverride value

Default value: `$puppetboard::override`

##### <a name="enable_ldap_auth"></a>`enable_ldap_auth`

Data type: `Boolean`

Whether to enable LDAP auth

Default value: `$puppetboard::enable_ldap_auth`

##### <a name="ldap_bind_dn"></a>`ldap_bind_dn`

Data type: `Optional[String[1]]`

LDAP Bind DN

Default value: ``undef``

##### <a name="ldap_bind_password"></a>`ldap_bind_password`

Data type: `Optional[String[1]]`

LDAP password

Default value: ``undef``

##### <a name="ldap_url"></a>`ldap_url`

Data type: `Optional[String[1]]`

LDAP connection string

Default value: ``undef``

##### <a name="ldap_bind_authoritative"></a>`ldap_bind_authoritative`

Data type: `Optional[String[1]]`

Determines if other authentication providers are used when a user can be mapped to a DN but the server cannot bind with the credentials

Default value: ``undef``

##### <a name="ldap_require_group"></a>`ldap_require_group`

Data type: `Boolean`

LDAP group to require on login

Default value: `$puppetboard::ldap_require_group`

##### <a name="ldap_require_group_dn"></a>`ldap_require_group_dn`

Data type: `Optional[String[1]]`

LDAP group DN for LDAP group

Default value: ``undef``

##### <a name="virtualenv_dir"></a>`virtualenv_dir`

Data type: `Stdlib::Absolutepath`

Set location where virtualenv will be installed

Default value: `$puppetboard::virtualenv_dir`

##### <a name="custom_apache_parameters"></a>`custom_apache_parameters`

Data type: `Hash`

A hash passed to the `apache::vhost` for custom settings

Default value: `{}`

## Data types

### <a name="puppetboardsyslogpriority"></a>`Puppetboard::Syslogpriority`

type for the different Python log levels

Alias of

```puppet
Enum['debug', 'info', 'notice', 'warning', 'err', 'crit', 'alert', 'emerg']
```

